Class: Google::Apis::MybusinesslodgingV1::TimeOfDay

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinesslodging_v1/classes.rb,
lib/google/apis/mybusinesslodging_v1/representations.rb,
lib/google/apis/mybusinesslodging_v1/representations.rb

Overview

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeOfDay

Returns a new instance of TimeOfDay.



4066
4067
4068
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4066

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hoursFixnum

Hours of a day in 24 hour format. Must be greater than or equal to 0 and typically must be less than or equal to 23. An API may choose to allow the value "24:00:00" for scenarios like business closing time. Corresponds to the JSON property hours

Returns:

  • (Fixnum)


4045
4046
4047
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4045

def hours
  @hours
end

#minutesFixnum

Minutes of an hour. Must be greater than or equal to 0 and less than or equal to 59. Corresponds to the JSON property minutes

Returns:

  • (Fixnum)


4051
4052
4053
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4051

def minutes
  @minutes
end

#nanosFixnum

Fractions of seconds, in nanoseconds. Must be greater than or equal to 0 and less than or equal to 999,999,999. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


4057
4058
4059
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4057

def nanos
  @nanos
end

#secondsFixnum

Seconds of a minute. Must be greater than or equal to 0 and typically must be less than or equal to 59. An API may allow the value 60 if it allows leap- seconds. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


4064
4065
4066
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4064

def seconds
  @seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4071
4072
4073
4074
4075
4076
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4071

def update!(**args)
  @hours = args[:hours] if args.key?(:hours)
  @minutes = args[:minutes] if args.key?(:minutes)
  @nanos = args[:nanos] if args.key?(:nanos)
  @seconds = args[:seconds] if args.key?(:seconds)
end