Class: Google::Apis::MybusinesslodgingV1::Transportation
- Inherits:
-
Object
- Object
- Google::Apis::MybusinesslodgingV1::Transportation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/mybusinesslodging_v1/classes.rb,
lib/google/apis/mybusinesslodging_v1/representations.rb,
lib/google/apis/mybusinesslodging_v1/representations.rb
Overview
Vehicles or vehicular services facilitated or owned by the property.
Instance Attribute Summary collapse
-
#airport_shuttle ⇒ Boolean
(also: #airport_shuttle?)
Airport shuttle.
-
#airport_shuttle_exception ⇒ String
Airport shuttle exception.
-
#car_rental_on_property ⇒ Boolean
(also: #car_rental_on_property?)
Car rental on property.
-
#car_rental_on_property_exception ⇒ String
Car rental on property exception.
-
#free_airport_shuttle ⇒ Boolean
(also: #free_airport_shuttle?)
Free airport shuttle.
-
#free_airport_shuttle_exception ⇒ String
Free airport shuttle exception.
-
#free_private_car_service ⇒ Boolean
(also: #free_private_car_service?)
Free private car service.
-
#free_private_car_service_exception ⇒ String
Free private car service exception.
-
#local_shuttle ⇒ Boolean
(also: #local_shuttle?)
Local shuttle.
-
#local_shuttle_exception ⇒ String
Local shuttle exception.
-
#private_car_service ⇒ Boolean
(also: #private_car_service?)
Private car service.
-
#private_car_service_exception ⇒ String
Private car service exception.
-
#transfer ⇒ Boolean
(also: #transfer?)
Transfer.
-
#transfer_exception ⇒ String
Transfer exception.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Transportation
constructor
A new instance of Transportation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Transportation
Returns a new instance of Transportation.
4177 4178 4179 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4177 def initialize(**args) update!(**args) end |
Instance Attribute Details
#airport_shuttle ⇒ Boolean Also known as: airport_shuttle?
Airport shuttle. The hotel provides guests with a chauffeured van or bus to
and from the airport. Can be free or for a fee. Guests may share the vehicle
with other guests unknown to them. Applies if the hotel has a third-party
shuttle service (office/desk etc.) within the hotel. As long as hotel provides
this service, it doesn't matter if it's directly with them or a third party
they work with. Does not apply if guest has to coordinate with an entity
outside/other than the hotel.
Corresponds to the JSON property airportShuttle
4092 4093 4094 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4092 def airport_shuttle @airport_shuttle end |
#airport_shuttle_exception ⇒ String
Airport shuttle exception.
Corresponds to the JSON property airportShuttleException
4098 4099 4100 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4098 def airport_shuttle_exception @airport_shuttle_exception end |
#car_rental_on_property ⇒ Boolean Also known as: car_rental_on_property?
Car rental on property. A branch of a rental car company with a processing
desk in the hotel. Available cars for rent may be awaiting at the hotel or in
a nearby lot.
Corresponds to the JSON property carRentalOnProperty
4105 4106 4107 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4105 def car_rental_on_property @car_rental_on_property end |
#car_rental_on_property_exception ⇒ String
Car rental on property exception.
Corresponds to the JSON property carRentalOnPropertyException
4111 4112 4113 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4111 def car_rental_on_property_exception @car_rental_on_property_exception end |
#free_airport_shuttle ⇒ Boolean Also known as: free_airport_shuttle?
Free airport shuttle. Airport shuttle is free to guests. Must be free to all
guests without any conditions.
Corresponds to the JSON property freeAirportShuttle
4117 4118 4119 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4117 def free_airport_shuttle @free_airport_shuttle end |
#free_airport_shuttle_exception ⇒ String
Free airport shuttle exception.
Corresponds to the JSON property freeAirportShuttleException
4123 4124 4125 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4123 def free_airport_shuttle_exception @free_airport_shuttle_exception end |
#free_private_car_service ⇒ Boolean Also known as: free_private_car_service?
Free private car service. Private chauffeured car service is free to guests.
Corresponds to the JSON property freePrivateCarService
4128 4129 4130 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4128 def free_private_car_service @free_private_car_service end |
#free_private_car_service_exception ⇒ String
Free private car service exception.
Corresponds to the JSON property freePrivateCarServiceException
4134 4135 4136 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4134 def free_private_car_service_exception @free_private_car_service_exception end |
#local_shuttle ⇒ Boolean Also known as: local_shuttle?
Local shuttle. A car, van or bus provided by the hotel to transport guests to
destinations within a specified range of distance around the hotel. Usually
shopping and/or convention centers, downtown districts, or beaches. Can be
free or for a fee.
Corresponds to the JSON property localShuttle
4142 4143 4144 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4142 def local_shuttle @local_shuttle end |
#local_shuttle_exception ⇒ String
Local shuttle exception.
Corresponds to the JSON property localShuttleException
4148 4149 4150 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4148 def local_shuttle_exception @local_shuttle_exception end |
#private_car_service ⇒ Boolean Also known as: private_car_service?
Private car service. Hotel provides a private chauffeured car to transport
guests to destinations. Passengers in the car are either alone or are known to
one another and have requested the car together. Service can be free or for a
fee and travel distance is usually limited to a specific range. Not a taxi.
Corresponds to the JSON property privateCarService
4156 4157 4158 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4156 def private_car_service @private_car_service end |
#private_car_service_exception ⇒ String
Private car service exception.
Corresponds to the JSON property privateCarServiceException
4162 4163 4164 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4162 def private_car_service_exception @private_car_service_exception end |
#transfer ⇒ Boolean Also known as: transfer?
Transfer. Hotel provides a shuttle service or car service to take guests to
and from the nearest airport or train station. Can be free or for a fee.
Guests may share the vehicle with other guests unknown to them.
Corresponds to the JSON property transfer
4169 4170 4171 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4169 def transfer @transfer end |
#transfer_exception ⇒ String
Transfer exception.
Corresponds to the JSON property transferException
4175 4176 4177 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4175 def transfer_exception @transfer_exception end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4182 def update!(**args) @airport_shuttle = args[:airport_shuttle] if args.key?(:airport_shuttle) @airport_shuttle_exception = args[:airport_shuttle_exception] if args.key?(:airport_shuttle_exception) @car_rental_on_property = args[:car_rental_on_property] if args.key?(:car_rental_on_property) @car_rental_on_property_exception = args[:car_rental_on_property_exception] if args.key?(:car_rental_on_property_exception) @free_airport_shuttle = args[:free_airport_shuttle] if args.key?(:free_airport_shuttle) @free_airport_shuttle_exception = args[:free_airport_shuttle_exception] if args.key?(:free_airport_shuttle_exception) @free_private_car_service = args[:free_private_car_service] if args.key?(:free_private_car_service) @free_private_car_service_exception = args[:free_private_car_service_exception] if args.key?(:free_private_car_service_exception) @local_shuttle = args[:local_shuttle] if args.key?(:local_shuttle) @local_shuttle_exception = args[:local_shuttle_exception] if args.key?(:local_shuttle_exception) @private_car_service = args[:private_car_service] if args.key?(:private_car_service) @private_car_service_exception = args[:private_car_service_exception] if args.key?(:private_car_service_exception) @transfer = args[:transfer] if args.key?(:transfer) @transfer_exception = args[:transfer_exception] if args.key?(:transfer_exception) end |