Class: Google::Apis::MybusinesslodgingV1::WaterConservation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinesslodging_v1/classes.rb,
lib/google/apis/mybusinesslodging_v1/representations.rb,
lib/google/apis/mybusinesslodging_v1/representations.rb

Overview

Water conservation practices implemented at the hotel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WaterConservation

Returns a new instance of WaterConservation.



4667
4668
4669
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4667

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#independent_organization_audits_water_useBoolean Also known as: independent_organization_audits_water_use?

Independent organization audits water use. The property conducts a water conservation audit every 5 years, the results of which are either verified by a third-party and/or published in external communications. A water conservation audit is a detailed assessment of the facility, providing recommendations to existing operations and procedures to improve water efficiency, available incentives or rebates, and opportunities for improvements through renovations or upgrades. Examples of organizations who conduct credible third party audits include: Engie Impact, and local utility providers (they often provide energy and water audits). Corresponds to the JSON property independentOrganizationAuditsWaterUse

Returns:

  • (Boolean)


4599
4600
4601
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4599

def independent_organization_audits_water_use
  @independent_organization_audits_water_use
end

#independent_organization_audits_water_use_exceptionString

Independent organization audits water use exception. Corresponds to the JSON property independentOrganizationAuditsWaterUseException

Returns:

  • (String)


4605
4606
4607
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4605

def independent_organization_audits_water_use_exception
  @independent_organization_audits_water_use_exception
end

#linen_reuse_programBoolean Also known as: linen_reuse_program?

Linen reuse program. The property offers a linen reuse program. Corresponds to the JSON property linenReuseProgram

Returns:

  • (Boolean)


4610
4611
4612
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4610

def linen_reuse_program
  @linen_reuse_program
end

#linen_reuse_program_exceptionString

Linen reuse program exception. Corresponds to the JSON property linenReuseProgramException

Returns:

  • (String)


4616
4617
4618
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4616

def linen_reuse_program_exception
  @linen_reuse_program_exception
end

#towel_reuse_programBoolean Also known as: towel_reuse_program?

Towel reuse program. The property offers a towel reuse program. Corresponds to the JSON property towelReuseProgram

Returns:

  • (Boolean)


4621
4622
4623
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4621

def towel_reuse_program
  @towel_reuse_program
end

#towel_reuse_program_exceptionString

Towel reuse program exception. Corresponds to the JSON property towelReuseProgramException

Returns:

  • (String)


4627
4628
4629
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4627

def towel_reuse_program_exception
  @towel_reuse_program_exception
end

#water_saving_showersBoolean Also known as: water_saving_showers?

Water saving showers. All of the property's guest rooms have shower heads that use no more than 2.0 gallons per minute (gpm). Corresponds to the JSON property waterSavingShowers

Returns:

  • (Boolean)


4633
4634
4635
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4633

def water_saving_showers
  @water_saving_showers
end

#water_saving_showers_exceptionString

Water saving showers exception. Corresponds to the JSON property waterSavingShowersException

Returns:

  • (String)


4639
4640
4641
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4639

def water_saving_showers_exception
  @water_saving_showers_exception
end

#water_saving_sinksBoolean Also known as: water_saving_sinks?

Water saving sinks. All of the property's guest rooms have bathroom faucets that use a maximum of 1.5 gallons per minute (gpm), public restroom faucets do not exceed 0.5 gpm, and kitchen faucets (excluding faucets used exclusively for filling operations) do not exceed 2.2 gpm. Corresponds to the JSON property waterSavingSinks

Returns:

  • (Boolean)


4647
4648
4649
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4647

def water_saving_sinks
  @water_saving_sinks
end

#water_saving_sinks_exceptionString

Water saving sinks exception. Corresponds to the JSON property waterSavingSinksException

Returns:

  • (String)


4653
4654
4655
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4653

def water_saving_sinks_exception
  @water_saving_sinks_exception
end

#water_saving_toiletsBoolean Also known as: water_saving_toilets?

Water saving toilets. All of the property's toilets use 1.6 gallons per flush, or less. Corresponds to the JSON property waterSavingToilets

Returns:

  • (Boolean)


4659
4660
4661
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4659

def water_saving_toilets
  @water_saving_toilets
end

#water_saving_toilets_exceptionString

Water saving toilets exception. Corresponds to the JSON property waterSavingToiletsException

Returns:

  • (String)


4665
4666
4667
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4665

def water_saving_toilets_exception
  @water_saving_toilets_exception
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
4685
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4672

def update!(**args)
  @independent_organization_audits_water_use = args[:independent_organization_audits_water_use] if args.key?(:independent_organization_audits_water_use)
  @independent_organization_audits_water_use_exception = args[:independent_organization_audits_water_use_exception] if args.key?(:independent_organization_audits_water_use_exception)
  @linen_reuse_program = args[:linen_reuse_program] if args.key?(:linen_reuse_program)
  @linen_reuse_program_exception = args[:linen_reuse_program_exception] if args.key?(:linen_reuse_program_exception)
  @towel_reuse_program = args[:towel_reuse_program] if args.key?(:towel_reuse_program)
  @towel_reuse_program_exception = args[:towel_reuse_program_exception] if args.key?(:towel_reuse_program_exception)
  @water_saving_showers = args[:water_saving_showers] if args.key?(:water_saving_showers)
  @water_saving_showers_exception = args[:water_saving_showers_exception] if args.key?(:water_saving_showers_exception)
  @water_saving_sinks = args[:water_saving_sinks] if args.key?(:water_saving_sinks)
  @water_saving_sinks_exception = args[:water_saving_sinks_exception] if args.key?(:water_saving_sinks_exception)
  @water_saving_toilets = args[:water_saving_toilets] if args.key?(:water_saving_toilets)
  @water_saving_toilets_exception = args[:water_saving_toilets_exception] if args.key?(:water_saving_toilets_exception)
end