Class: Google::Apis::MybusinesslodgingV1::Wellness

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/mybusinesslodging_v1/classes.rb,
lib/google/apis/mybusinesslodging_v1/representations.rb,
lib/google/apis/mybusinesslodging_v1/representations.rb

Overview

Guest facilities at the property to promote or maintain health, beauty, and fitness.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Wellness

Returns a new instance of Wellness.



4849
4850
4851
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#doctor_on_callBoolean Also known as: doctor_on_call?

Doctor on call. The hotel has a contract with a medical professional who provides services to hotel guests should they fall ill during their stay. The doctor may or may not have an on-site office or be at the hotel at all times. Corresponds to the JSON property doctorOnCall

Returns:

  • (Boolean)


4698
4699
4700
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4698

def doctor_on_call
  @doctor_on_call
end

#doctor_on_call_exceptionString

Doctor on call exception. Corresponds to the JSON property doctorOnCallException

Returns:

  • (String)


4704
4705
4706
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4704

def doctor_on_call_exception
  @doctor_on_call_exception
end

#elliptical_machineBoolean Also known as: elliptical_machine?

Elliptical machine. An electric, stationary fitness machine with pedals that simulates climbing, walking or running and provides a user-controlled range of speeds and tensions. May not have arm-controlled levers to work out the upper body as well. Commonly found in a gym, fitness room, health center, or health club. Corresponds to the JSON property ellipticalMachine

Returns:

  • (Boolean)


4713
4714
4715
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4713

def elliptical_machine
  @elliptical_machine
end

#elliptical_machine_exceptionString

Elliptical machine exception. Corresponds to the JSON property ellipticalMachineException

Returns:

  • (String)


4719
4720
4721
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4719

def elliptical_machine_exception
  @elliptical_machine_exception
end

#fitness_centerBoolean Also known as: fitness_center?

Fitness center. A room or building at the hotel containing equipment to promote physical activity, such as treadmills, elliptical machines, stationary bikes, weight machines, free weights, and/or stretching mats. Use of the fitness center can be free or for a fee. May or may not be staffed. May or may not offer instructor-led classes in various styles of physical conditioning. May or may not be open 24/7. May or may not include locker rooms and showers. Also known as health club, gym, fitness room, health center. Corresponds to the JSON property fitnessCenter

Returns:

  • (Boolean)


4730
4731
4732
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4730

def fitness_center
  @fitness_center
end

#fitness_center_exceptionString

Fitness center exception. Corresponds to the JSON property fitnessCenterException

Returns:

  • (String)


4736
4737
4738
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4736

def fitness_center_exception
  @fitness_center_exception
end

#free_fitness_centerBoolean Also known as: free_fitness_center?

Free fitness center. Guests may use the fitness center for free. Corresponds to the JSON property freeFitnessCenter

Returns:

  • (Boolean)


4741
4742
4743
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4741

def free_fitness_center
  @free_fitness_center
end

#free_fitness_center_exceptionString

Free fitness center exception. Corresponds to the JSON property freeFitnessCenterException

Returns:

  • (String)


4747
4748
4749
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4747

def free_fitness_center_exception
  @free_fitness_center_exception
end

#free_weightsBoolean Also known as: free_weights?

Free weights. Individual handheld fitness equipment of varied weights used for upper body strength training or bodybuilding. Also known as barbells, dumbbells, or kettlebells. Often stored on a rack with the weights arranged from light to heavy. Commonly found in a gym, fitness room, health center, or health club. Corresponds to the JSON property freeWeights

Returns:

  • (Boolean)


4756
4757
4758
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4756

def free_weights
  @free_weights
end

#free_weights_exceptionString

Free weights exception. Corresponds to the JSON property freeWeightsException

Returns:

  • (String)


4762
4763
4764
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4762

def free_weights_exception
  @free_weights_exception
end

#massageBoolean Also known as: massage?

Massage. A service provided by a trained massage therapist involving the physical manipulation of a guest's muscles in order to achieve relaxation or pain relief. Corresponds to the JSON property massage

Returns:

  • (Boolean)


4769
4770
4771
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4769

def massage
  @massage
end

#massage_exceptionString

Massage exception. Corresponds to the JSON property massageException

Returns:

  • (String)


4775
4776
4777
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4775

def massage_exception
  @massage_exception
end

#salonBoolean Also known as: salon?

Salon. A room at the hotel where professionals provide hair styling services such as shampooing, blow drying, hair dos, hair cutting and hair coloring. Also known as hairdresser or beauty salon. Corresponds to the JSON property salon

Returns:

  • (Boolean)


4782
4783
4784
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4782

def salon
  @salon
end

#salon_exceptionString

Salon exception. Corresponds to the JSON property salonException

Returns:

  • (String)


4788
4789
4790
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4788

def salon_exception
  @salon_exception
end

#saunaBoolean Also known as: sauna?

Sauna. A wood-paneled room heated to a high temperature where guests sit on built-in wood benches for the purpose of perspiring and relaxing their muscles. Can be dry or slightly wet heat. Not a steam room. Corresponds to the JSON property sauna

Returns:

  • (Boolean)


4795
4796
4797
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4795

def sauna
  @sauna
end

#sauna_exceptionString

Sauna exception. Corresponds to the JSON property saunaException

Returns:

  • (String)


4801
4802
4803
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4801

def sauna_exception
  @sauna_exception
end

#spaBoolean Also known as: spa?

Spa. A designated area, room or building at the hotel offering health and beauty treatment through such means as steam baths, exercise equipment, and massage. May also offer facials, nail care, and hair care. Services are usually available by appointment and for an additional fee. Does not apply if hotel only offers a steam room; must offer other beauty and/or health treatments as well. Corresponds to the JSON property spa

Returns:

  • (Boolean)


4811
4812
4813
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4811

def spa
  @spa
end

#spa_exceptionString

Spa exception. Corresponds to the JSON property spaException

Returns:

  • (String)


4817
4818
4819
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4817

def spa_exception
  @spa_exception
end

#treadmillBoolean Also known as: treadmill?

Treadmill. An electric stationary fitness machine that simulates a moving path to promote walking or running within a range of user-controlled speeds and inclines. Also known as running machine. Commonly found in a gym, fitness room, health center, or health club. Corresponds to the JSON property treadmill

Returns:

  • (Boolean)


4825
4826
4827
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4825

def treadmill
  @treadmill
end

#treadmill_exceptionString

Treadmill exception. Corresponds to the JSON property treadmillException

Returns:

  • (String)


4831
4832
4833
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4831

def treadmill_exception
  @treadmill_exception
end

#weight_machineBoolean Also known as: weight_machine?

Weight machine. Non-electronic fitness equipment designed for the user to target the exertion of different muscles. Usually incorporates a padded seat, a stack of flat weights and various bars and pulleys. May be designed for toning a specific part of the body or may involve different user-controlled settings, hardware and pulleys so as to provide an overall workout in one machine. Commonly found in a gym, fitness center, fitness room, or health club. Corresponds to the JSON property weightMachine

Returns:

  • (Boolean)


4841
4842
4843
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4841

def weight_machine
  @weight_machine
end

#weight_machine_exceptionString

Weight machine exception. Corresponds to the JSON property weightMachineException

Returns:

  • (String)


4847
4848
4849
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4847

def weight_machine_exception
  @weight_machine_exception
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
4864
4865
4866
4867
4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4854

def update!(**args)
  @doctor_on_call = args[:doctor_on_call] if args.key?(:doctor_on_call)
  @doctor_on_call_exception = args[:doctor_on_call_exception] if args.key?(:doctor_on_call_exception)
  @elliptical_machine = args[:elliptical_machine] if args.key?(:elliptical_machine)
  @elliptical_machine_exception = args[:elliptical_machine_exception] if args.key?(:elliptical_machine_exception)
  @fitness_center = args[:fitness_center] if args.key?(:fitness_center)
  @fitness_center_exception = args[:fitness_center_exception] if args.key?(:fitness_center_exception)
  @free_fitness_center = args[:free_fitness_center] if args.key?(:free_fitness_center)
  @free_fitness_center_exception = args[:free_fitness_center_exception] if args.key?(:free_fitness_center_exception)
  @free_weights = args[:free_weights] if args.key?(:free_weights)
  @free_weights_exception = args[:free_weights_exception] if args.key?(:free_weights_exception)
  @massage = args[:massage] if args.key?(:massage)
  @massage_exception = args[:massage_exception] if args.key?(:massage_exception)
  @salon = args[:salon] if args.key?(:salon)
  @salon_exception = args[:salon_exception] if args.key?(:salon_exception)
  @sauna = args[:sauna] if args.key?(:sauna)
  @sauna_exception = args[:sauna_exception] if args.key?(:sauna_exception)
  @spa = args[:spa] if args.key?(:spa)
  @spa_exception = args[:spa_exception] if args.key?(:spa_exception)
  @treadmill = args[:treadmill] if args.key?(:treadmill)
  @treadmill_exception = args[:treadmill_exception] if args.key?(:treadmill_exception)
  @weight_machine = args[:weight_machine] if args.key?(:weight_machine)
  @weight_machine_exception = args[:weight_machine_exception] if args.key?(:weight_machine_exception)
end