Class: Google::Apis::MybusinesslodgingV1::WasteReduction
- Inherits:
-
Object
- Object
- Google::Apis::MybusinesslodgingV1::WasteReduction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/mybusinesslodging_v1/classes.rb,
lib/google/apis/mybusinesslodging_v1/representations.rb,
lib/google/apis/mybusinesslodging_v1/representations.rb
Overview
Waste reduction practices implemented at the hotel.
Instance Attribute Summary collapse
-
#compostable_food_containers_and_cutlery ⇒ Boolean
(also: #compostable_food_containers_and_cutlery?)
Compostable food containers and cutlery.
-
#compostable_food_containers_and_cutlery_exception ⇒ String
Compostable food containers and cutlery exception.
-
#composts_excess_food ⇒ Boolean
(also: #composts_excess_food?)
Composts excess food.
-
#composts_excess_food_exception ⇒ String
Composts excess food exception.
-
#donates_excess_food ⇒ Boolean
(also: #donates_excess_food?)
Donates excess food.
-
#donates_excess_food_exception ⇒ String
Donates excess food exception.
-
#food_waste_reduction_program ⇒ Boolean
(also: #food_waste_reduction_program?)
Food waste reduction program.
-
#food_waste_reduction_program_exception ⇒ String
Food waste reduction program exception.
-
#no_single_use_plastic_straws ⇒ Boolean
(also: #no_single_use_plastic_straws?)
No single use plastic straws.
-
#no_single_use_plastic_straws_exception ⇒ String
No single use plastic straws exception.
-
#no_single_use_plastic_water_bottles ⇒ Boolean
(also: #no_single_use_plastic_water_bottles?)
No single use plastic water bottles.
-
#no_single_use_plastic_water_bottles_exception ⇒ String
No single use plastic water bottles exception.
-
#no_styrofoam_food_containers ⇒ Boolean
(also: #no_styrofoam_food_containers?)
No styrofoam food containers.
-
#no_styrofoam_food_containers_exception ⇒ String
No styrofoam food containers exception.
-
#recycling_program ⇒ Boolean
(also: #recycling_program?)
Recycling program.
-
#recycling_program_exception ⇒ String
Recycling program exception.
-
#refillable_toiletry_containers ⇒ Boolean
(also: #refillable_toiletry_containers?)
Refillable toiletry containers.
-
#refillable_toiletry_containers_exception ⇒ String
Refillable toiletry containers exception.
-
#safely_disposes_batteries ⇒ Boolean
(also: #safely_disposes_batteries?)
Safely disposes batteries.
-
#safely_disposes_batteries_exception ⇒ String
Safely disposes batteries exception.
-
#safely_disposes_electronics ⇒ Boolean
(also: #safely_disposes_electronics?)
Safely disposes electronics.
-
#safely_disposes_electronics_exception ⇒ String
Safely disposes electronics exception.
-
#safely_disposes_lightbulbs ⇒ Boolean
(also: #safely_disposes_lightbulbs?)
Safely disposes lightbulbs.
-
#safely_disposes_lightbulbs_exception ⇒ String
Safely disposes lightbulbs exception.
-
#safely_handles_hazardous_substances ⇒ Boolean
(also: #safely_handles_hazardous_substances?)
Safely handles hazardous substances.
-
#safely_handles_hazardous_substances_exception ⇒ String
Safely handles hazardous substances exception.
-
#soap_donation_program ⇒ Boolean
(also: #soap_donation_program?)
Soap donation program.
-
#soap_donation_program_exception ⇒ String
Soap donation program exception.
-
#toiletry_donation_program ⇒ Boolean
(also: #toiletry_donation_program?)
Toiletry donation program.
-
#toiletry_donation_program_exception ⇒ String
Toiletry donation program exception.
-
#water_bottle_filling_stations ⇒ Boolean
(also: #water_bottle_filling_stations?)
Water bottle filling stations.
-
#water_bottle_filling_stations_exception ⇒ String
Water bottle filling stations exception.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WasteReduction
constructor
A new instance of WasteReduction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WasteReduction
Returns a new instance of WasteReduction.
4543 4544 4545 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4543 def initialize(**args) update!(**args) end |
Instance Attribute Details
#compostable_food_containers_and_cutlery ⇒ Boolean Also known as: compostable_food_containers_and_cutlery?
Compostable food containers and cutlery. 100% of food service containers and
to-go cutlery are compostable, and reusable utensils are offered wherever
possible. Compostable materials are capable of undergoing biological
decomposition in a compost site, such that material is not visually
distinguishable and breaks down into carbon dioxide, water, inorganic
compounds, and biomass.
Corresponds to the JSON property compostableFoodContainersAndCutlery
4337 4338 4339 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4337 def compostable_food_containers_and_cutlery @compostable_food_containers_and_cutlery end |
#compostable_food_containers_and_cutlery_exception ⇒ String
Compostable food containers and cutlery exception.
Corresponds to the JSON property compostableFoodContainersAndCutleryException
4343 4344 4345 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4343 def compostable_food_containers_and_cutlery_exception @compostable_food_containers_and_cutlery_exception end |
#composts_excess_food ⇒ Boolean Also known as: composts_excess_food?
Composts excess food. The property has a program and/or policy for diverting
waste from landfill by composting food and yard waste, either through compost
collection and off-site processing or on-site compost processing.
Corresponds to the JSON property compostsExcessFood
4350 4351 4352 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4350 def composts_excess_food @composts_excess_food end |
#composts_excess_food_exception ⇒ String
Composts excess food exception.
Corresponds to the JSON property compostsExcessFoodException
4356 4357 4358 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4356 def composts_excess_food_exception @composts_excess_food_exception end |
#donates_excess_food ⇒ Boolean Also known as: donates_excess_food?
Donates excess food. The property has a program and/or policy for diverting
waste from landfill that may include efforts to donate for human consumption
or divert food for animal feed.
Corresponds to the JSON property donatesExcessFood
4363 4364 4365 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4363 def donates_excess_food @donates_excess_food end |
#donates_excess_food_exception ⇒ String
Donates excess food exception.
Corresponds to the JSON property donatesExcessFoodException
4369 4370 4371 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4369 def donates_excess_food_exception @donates_excess_food_exception end |
#food_waste_reduction_program ⇒ Boolean Also known as: food_waste_reduction_program?
Food waste reduction program. The property has established a food waste
reduction and donation program, aiming to reduce food waste by half. These
programs typically use tools such as the Hotel Kitchen Toolkit and others to
track waste and measure progress.
Corresponds to the JSON property foodWasteReductionProgram
4377 4378 4379 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4377 def food_waste_reduction_program @food_waste_reduction_program end |
#food_waste_reduction_program_exception ⇒ String
Food waste reduction program exception.
Corresponds to the JSON property foodWasteReductionProgramException
4383 4384 4385 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4383 def food_waste_reduction_program_exception @food_waste_reduction_program_exception end |
#no_single_use_plastic_straws ⇒ Boolean Also known as: no_single_use_plastic_straws?
No single use plastic straws. The property bans single-use plastic straws.
Corresponds to the JSON property noSingleUsePlasticStraws
4388 4389 4390 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4388 def no_single_use_plastic_straws @no_single_use_plastic_straws end |
#no_single_use_plastic_straws_exception ⇒ String
No single use plastic straws exception.
Corresponds to the JSON property noSingleUsePlasticStrawsException
4394 4395 4396 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4394 def no_single_use_plastic_straws_exception @no_single_use_plastic_straws_exception end |
#no_single_use_plastic_water_bottles ⇒ Boolean Also known as: no_single_use_plastic_water_bottles?
No single use plastic water bottles. The property bans single-use plastic
water bottles.
Corresponds to the JSON property noSingleUsePlasticWaterBottles
4400 4401 4402 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4400 def no_single_use_plastic_water_bottles @no_single_use_plastic_water_bottles end |
#no_single_use_plastic_water_bottles_exception ⇒ String
No single use plastic water bottles exception.
Corresponds to the JSON property noSingleUsePlasticWaterBottlesException
4406 4407 4408 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4406 def no_single_use_plastic_water_bottles_exception @no_single_use_plastic_water_bottles_exception end |
#no_styrofoam_food_containers ⇒ Boolean Also known as: no_styrofoam_food_containers?
No styrofoam food containers. The property eliminates the use of Styrofoam in
disposable food service items.
Corresponds to the JSON property noStyrofoamFoodContainers
4412 4413 4414 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4412 def no_styrofoam_food_containers @no_styrofoam_food_containers end |
#no_styrofoam_food_containers_exception ⇒ String
No styrofoam food containers exception.
Corresponds to the JSON property noStyrofoamFoodContainersException
4418 4419 4420 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4418 def no_styrofoam_food_containers_exception @no_styrofoam_food_containers_exception end |
#recycling_program ⇒ Boolean Also known as: recycling_program?
Recycling program. The property has a recycling program, aligned with LEED
waste requirements, and a policy outlining efforts to send less than 50% of
waste to landfill. The recycling program includes storage locations for
recyclable materials, including mixed paper, corrugated cardboard, glass,
plastics, and metals.
Corresponds to the JSON property recyclingProgram
4427 4428 4429 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4427 def recycling_program @recycling_program end |
#recycling_program_exception ⇒ String
Recycling program exception.
Corresponds to the JSON property recyclingProgramException
4433 4434 4435 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4433 def recycling_program_exception @recycling_program_exception end |
#refillable_toiletry_containers ⇒ Boolean Also known as: refillable_toiletry_containers?
Refillable toiletry containers. The property has replaced miniature individual
containers with refillable amenity dispensers for shampoo, conditioner, soap,
and lotion.
Corresponds to the JSON property refillableToiletryContainers
4440 4441 4442 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4440 def refillable_toiletry_containers @refillable_toiletry_containers end |
#refillable_toiletry_containers_exception ⇒ String
Refillable toiletry containers exception.
Corresponds to the JSON property refillableToiletryContainersException
4446 4447 4448 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4446 def refillable_toiletry_containers_exception @refillable_toiletry_containers_exception end |
#safely_disposes_batteries ⇒ Boolean Also known as: safely_disposes_batteries?
Safely disposes batteries. The property safely stores and disposes batteries.
Corresponds to the JSON property safelyDisposesBatteries
4451 4452 4453 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4451 def safely_disposes_batteries @safely_disposes_batteries end |
#safely_disposes_batteries_exception ⇒ String
Safely disposes batteries exception.
Corresponds to the JSON property safelyDisposesBatteriesException
4457 4458 4459 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4457 def safely_disposes_batteries_exception @safely_disposes_batteries_exception end |
#safely_disposes_electronics ⇒ Boolean Also known as: safely_disposes_electronics?
Safely disposes electronics. The property has a reputable recycling program
that keeps hazardous electronic parts and chemical compounds out of landfills,
dumps and other unauthorized abandonment sites, and recycles/reuses applicable
materials. (e.g. certified electronics recyclers).
Corresponds to the JSON property safelyDisposesElectronics
4465 4466 4467 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4465 def safely_disposes_electronics @safely_disposes_electronics end |
#safely_disposes_electronics_exception ⇒ String
Safely disposes electronics exception.
Corresponds to the JSON property safelyDisposesElectronicsException
4471 4472 4473 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4471 def safely_disposes_electronics_exception @safely_disposes_electronics_exception end |
#safely_disposes_lightbulbs ⇒ Boolean Also known as: safely_disposes_lightbulbs?
Safely disposes lightbulbs. The property safely stores and disposes lightbulbs.
Corresponds to the JSON property safelyDisposesLightbulbs
4476 4477 4478 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4476 def safely_disposes_lightbulbs @safely_disposes_lightbulbs end |
#safely_disposes_lightbulbs_exception ⇒ String
Safely disposes lightbulbs exception.
Corresponds to the JSON property safelyDisposesLightbulbsException
4482 4483 4484 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4482 def safely_disposes_lightbulbs_exception @safely_disposes_lightbulbs_exception end |
#safely_handles_hazardous_substances ⇒ Boolean Also known as: safely_handles_hazardous_substances?
Safely handles hazardous substances. The property has a hazardous waste
management program aligned wit GreenSeal and LEED requirements, and meets all
regulatory requirements for hazardous waste disposal and recycling. Hazardous
means substances that are classified as "hazardous" by an authoritative body (
such as OSHA or DOT), are labeled with signal words such as "Danger," "Caution,
" "Warning," or are flammable, corrosive, or ignitable. Requirements include: -
The property shall maintain records of the efforts it has made to replace the
hazardous substances it uses with less hazardous alternatives. - An inventory
of the hazardous materials stored on-site. - Products intended for cleaning,
dishwashing, laundry, and pool maintenance shall be stored in clearly labeled
containers. These containers shall be checked regularly for leaks, and
replaced a necessary. - Spill containment devices shall be installed to
collect spills, drips, or leaching of chemicals.
Corresponds to the JSON property safelyHandlesHazardousSubstances
4499 4500 4501 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4499 def safely_handles_hazardous_substances @safely_handles_hazardous_substances end |
#safely_handles_hazardous_substances_exception ⇒ String
Safely handles hazardous substances exception.
Corresponds to the JSON property safelyHandlesHazardousSubstancesException
4505 4506 4507 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4505 def safely_handles_hazardous_substances_exception @safely_handles_hazardous_substances_exception end |
#soap_donation_program ⇒ Boolean Also known as: soap_donation_program?
Soap donation program. The property participates in a soap donation program
such as Clean the World or something similar.
Corresponds to the JSON property soapDonationProgram
4511 4512 4513 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4511 def soap_donation_program @soap_donation_program end |
#soap_donation_program_exception ⇒ String
Soap donation program exception.
Corresponds to the JSON property soapDonationProgramException
4517 4518 4519 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4517 def soap_donation_program_exception @soap_donation_program_exception end |
#toiletry_donation_program ⇒ Boolean Also known as: toiletry_donation_program?
Toiletry donation program. The property participates in a toiletry donation
program such as Clean the World or something similar.
Corresponds to the JSON property toiletryDonationProgram
4523 4524 4525 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4523 def toiletry_donation_program @toiletry_donation_program end |
#toiletry_donation_program_exception ⇒ String
Toiletry donation program exception.
Corresponds to the JSON property toiletryDonationProgramException
4529 4530 4531 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4529 def toiletry_donation_program_exception @toiletry_donation_program_exception end |
#water_bottle_filling_stations ⇒ Boolean Also known as: water_bottle_filling_stations?
Water bottle filling stations. The property offers water stations throughout
the building for guest use.
Corresponds to the JSON property waterBottleFillingStations
4535 4536 4537 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4535 def water_bottle_filling_stations @water_bottle_filling_stations end |
#water_bottle_filling_stations_exception ⇒ String
Water bottle filling stations exception.
Corresponds to the JSON property waterBottleFillingStationsException
4541 4542 4543 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4541 def water_bottle_filling_stations_exception @water_bottle_filling_stations_exception end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4548 4549 4550 4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 4578 4579 4580 4581 |
# File 'lib/google/apis/mybusinesslodging_v1/classes.rb', line 4548 def update!(**args) @compostable_food_containers_and_cutlery = args[:compostable_food_containers_and_cutlery] if args.key?(:compostable_food_containers_and_cutlery) @compostable_food_containers_and_cutlery_exception = args[:compostable_food_containers_and_cutlery_exception] if args.key?(:compostable_food_containers_and_cutlery_exception) @composts_excess_food = args[:composts_excess_food] if args.key?(:composts_excess_food) @composts_excess_food_exception = args[:composts_excess_food_exception] if args.key?(:composts_excess_food_exception) @donates_excess_food = args[:donates_excess_food] if args.key?(:donates_excess_food) @donates_excess_food_exception = args[:donates_excess_food_exception] if args.key?(:donates_excess_food_exception) @food_waste_reduction_program = args[:food_waste_reduction_program] if args.key?(:food_waste_reduction_program) @food_waste_reduction_program_exception = args[:food_waste_reduction_program_exception] if args.key?(:food_waste_reduction_program_exception) @no_single_use_plastic_straws = args[:no_single_use_plastic_straws] if args.key?(:no_single_use_plastic_straws) @no_single_use_plastic_straws_exception = args[:no_single_use_plastic_straws_exception] if args.key?(:no_single_use_plastic_straws_exception) @no_single_use_plastic_water_bottles = args[:no_single_use_plastic_water_bottles] if args.key?(:no_single_use_plastic_water_bottles) @no_single_use_plastic_water_bottles_exception = args[:no_single_use_plastic_water_bottles_exception] if args.key?(:no_single_use_plastic_water_bottles_exception) @no_styrofoam_food_containers = args[:no_styrofoam_food_containers] if args.key?(:no_styrofoam_food_containers) @no_styrofoam_food_containers_exception = args[:no_styrofoam_food_containers_exception] if args.key?(:no_styrofoam_food_containers_exception) @recycling_program = args[:recycling_program] if args.key?(:recycling_program) @recycling_program_exception = args[:recycling_program_exception] if args.key?(:recycling_program_exception) @refillable_toiletry_containers = args[:refillable_toiletry_containers] if args.key?(:refillable_toiletry_containers) @refillable_toiletry_containers_exception = args[:refillable_toiletry_containers_exception] if args.key?(:refillable_toiletry_containers_exception) @safely_disposes_batteries = args[:safely_disposes_batteries] if args.key?(:safely_disposes_batteries) @safely_disposes_batteries_exception = args[:safely_disposes_batteries_exception] if args.key?(:safely_disposes_batteries_exception) @safely_disposes_electronics = args[:safely_disposes_electronics] if args.key?(:safely_disposes_electronics) @safely_disposes_electronics_exception = args[:safely_disposes_electronics_exception] if args.key?(:safely_disposes_electronics_exception) @safely_disposes_lightbulbs = args[:safely_disposes_lightbulbs] if args.key?(:safely_disposes_lightbulbs) @safely_disposes_lightbulbs_exception = args[:safely_disposes_lightbulbs_exception] if args.key?(:safely_disposes_lightbulbs_exception) @safely_handles_hazardous_substances = args[:safely_handles_hazardous_substances] if args.key?(:safely_handles_hazardous_substances) @safely_handles_hazardous_substances_exception = args[:safely_handles_hazardous_substances_exception] if args.key?(:safely_handles_hazardous_substances_exception) @soap_donation_program = args[:soap_donation_program] if args.key?(:soap_donation_program) @soap_donation_program_exception = args[:soap_donation_program_exception] if args.key?(:soap_donation_program_exception) @toiletry_donation_program = args[:toiletry_donation_program] if args.key?(:toiletry_donation_program) @toiletry_donation_program_exception = args[:toiletry_donation_program_exception] if args.key?(:toiletry_donation_program_exception) @water_bottle_filling_stations = args[:water_bottle_filling_stations] if args.key?(:water_bottle_filling_stations) @water_bottle_filling_stations_exception = args[:water_bottle_filling_stations_exception] if args.key?(:water_bottle_filling_stations_exception) end |